@@ -4,7 +4,7 @@ from poisson_approval.profiles.ProfileCardinal import ProfileCardinal
 from poisson_approval.strategies.StrategyThreshold import StrategyThreshold
 from poisson_approval.utils.DictPrintingInOrderIgnoringZeros import DictPrintingInOrderIgnoringZeros
 from poisson_approval.utils.Util import product_dict, my_division
-from poisson_approval.utils.UtilPreferences import is_weak_order, sort_weak_order
+from poisson_approval.utils.UtilPreferences import is_weak_order, sort_weak_order, is_hater
 from poisson_approval.utils.UtilCache import cached_property
 
 
@@ -82,6 +82,10 @@ class ProfileDiscrete(ProfileCardinal):
         Fraction(13, 50)
         >>> profile.have_ranking_with_utility_u('abc', 0.3)
         Fraction(13, 50)
+        >>> profile.d_candidate_welfare
+        {'a': 0.811, 'b': 0.712, 'c': 0}
+        >>> profile.d_candidate_relative_welfare
+        {'a': 1.0, 'b': 0.877928483353884, 'c': 0.0}
         >>> profile.analyzed_strategies_pure
         Equilibrium:
         <abc: a, bac: b> ==> a (FF)
@@ -320,6 +324,20 @@ ratio_sincere=Fraction(1, 10), ratio_fanatic=Fraction(1, 5))
                                ratio_sincere=self.ratio_sincere, ratio_fanatic=self.ratio_fanatic,
                                voting_rule=self.voting_rule)
 
+    @cached_property
+    def d_candidate_welfare(self):
+        d = {candidate: 0 for candidate in CANDIDATES}
+        for ranking, d_utility_share in self.d_ranking_utility_share.items():
+            for utility, share in d_utility_share.items():
+                d[ranking[0]] += share
+                d[ranking[1]] += utility * share
+        for weak_order, share in self.d_weak_order_share.items():
+            if share > 0:
+                d[weak_order[0]] += share
+                if is_hater(weak_order):
+                    d[weak_order[2]] += share
+        return d
+
     @property
     def strategies_pure(self):
         """Iterator: pure strategies of the profile.
